.. _spkg_rfc3339_validator:

rfc3339_validator: A pure python RFC3339 validator
==================================================

Description
-----------

A pure python RFC3339 validator

License
-------

MIT license

Upstream Contact
----------------

https://pypi.org/project/rfc3339-validator/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    0.1.4

version_requirements.txt::

    rfc3339-validator

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install rfc3339-validator

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i rfc3339_validator

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-rfc3339-validator


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
